@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, print_function, unicode_literals
+from . import __version__
 from . import _tty as tty
 from .core import Cider
 from subprocess import CalledProcessError
@@ -8,9 +9,11 @@ import click
 import sys
 
 from .exceptions import (
-    BrewMissingError, CiderException, JSONError, XcodeMissingError
+    BrewMissingError, CiderException, JSONError
 )
 
+CONTEXT_SETTINGS = {"help_option_names": ['-h', '--help']}
+
 
 class CLI(click.Group):
     def __init__(self, **attrs):
@@ -28,15 +31,15 @@ class CLI(click.Group):
             "{0} tap missing",
             "{0} set-default [-g] NAME KEY VALUE",
             "{0} remove-default [-g] NAME KEY",
-            "{0} apply-defaults",
+            "{0} addlink NAME ITEM...",
+            "{0} unlink NAME",
             "{0} set-icon APP ICON",
             "{0} remove-icon APP",
+            "{0} apply-defaults",
             "{0} apply-icons",
             "{0} run-scripts",
             "{0} restore",
             "{0} relink",
-            "{0} addlink NAME ITEM...",
-            "{0} unlink"
         ]
 
         basename = ctx.command_path
@@ -54,9 +57,17 @@ class CLI(click.Group):
         return click.Group.get_command(self, ctx, command)
 
 
-@click.group(cls=CLI)
+def print_version(ctx, param, value):  # # pylint: disable=W0613
+    if value or not ctx.resilient_parsing:
+        print(__version__)
+        ctx.exit()
+
+
+@click.group(cls=CLI, context_settings=CONTEXT_SETTINGS)
 @click.option("-d", "--debug", is_flag=True)
 @click.option("-v", "--verbose", is_flag=True)
+@click.option("--version", is_flag=True, callback=print_version,
+              expose_value=False, is_eager=True)
 @click.pass_context
 def cli(ctx, debug, verbose):
     ctx.obj = Cider(False, debug, verbose)
@@ -96,8 +107,9 @@ def cask(ctx, command, args, force=None):
 
 @cli.command()
 @click.pass_obj
-def restore(cider):
-    cider.restore()
+@click.option("-i", "--ignore-errors", is_flag=True)
+def restore(cider, ignore_errors):
+    cider.restore(ignore_errors=ignore_errors)
 
 
 @cli.command()
@@ -136,7 +148,7 @@ def untap(cider, tap):
 @click.option("-f", "--force", is_flag=True)
 @click.pass_obj
 def relink(cider, force=None):
-    cider.relink(force)
+    cider.relink(force=force)
 
 
 @cli.command("list")
@@ -246,11 +258,6 @@ def main():
             e.filepath,
             e.message
         ))
-    except XcodeMissingError as e:
-        print("First, you need to install Xcode (press any key to redirect)")
-        click.getchar()
-        urlopen(e.url)
-        sys.exit(1)
     except BrewMissingError as e:
         print("Next, install Homebrew (press any key to redirect)")
         click.getchar()
