@@ -6,6 +6,7 @@ from .exceptions import (
     UnsupportedOSError, XcodeMissingError, BrewMissingError,
     SymlinkError, AppMissingError, StowError
 )
+from ._lib import lazyproperty
 from ._sh import (
     Brew, Defaults, spawn, collapseuser, commonpath, curl, mkdir_p, read_json,
     write_json, modify_json, isdirname
@@ -14,6 +15,7 @@ from fnmatch import fnmatch
 from glob import iglob
 from rfc3987 import parse as urlparse
 from tempfile import mkdtemp
+import click
 import errno
 import json
 import os
@@ -33,34 +35,38 @@ class Cider(object):
         self.cask = cask if cask is not None else False
         self.debug = debug if debug is not None else False
         self.verbose = verbose if verbose is not None else False
-        self.brew = Brew(cask, debug, verbose)
-        self.defaults = Defaults(debug)
         self.cider_dir = cider_dir if cider_dir is not None else \
             self.fallback_cider_dir()
         self.support_dir = support_dir if support_dir is not None else \
             self.fallback_support_dir()
+        self.brew = Brew(cask, debug, verbose, self.env)
+        self.defaults = Defaults(debug, self.env)
 
-    @property
+    @lazyproperty
     def symlink_dir(self):
         return os.path.join(self.cider_dir, "symlinks")
 
-    @property
+    @lazyproperty
     def bootstrap_file(self):
         return os.path.join(self.cider_dir, "bootstrap.json")
 
-    @property
+    @lazyproperty
     def defaults_file(self):
         return os.path.join(self.cider_dir, "defaults.json")
 
-    @staticmethod
-    def fallback_cider_dir():
+    @lazyproperty
+    def env(self):
+        env = os.environ.copy()
+        env.update(self.read_bootstrap().get("env", {}))
+        return env
+
+    def fallback_cider_dir(self):
         try:
             return os.path.join(os.environ["XDG_CONFIG_HOME"], "cider")
         except KeyError:
             return os.path.join(os.path.expanduser("~"), ".cider")
 
-    @staticmethod
-    def fallback_support_dir():
+    def fallback_support_dir(self):
         try:
             return os.path.join(os.environ["XDG_DATA_HOME"], "cider")
         except KeyError:
@@ -71,7 +77,7 @@ class Cider(object):
                 "com.msanders.cider"
             )
 
-    @property
+    @lazyproperty
     def symlink_targets_file(self):
         return os.path.join(self.support_dir, "symlink_targets.json")
 
@@ -147,6 +153,16 @@ class Cider(object):
                     )
                 )
 
+    def _has_xcode_tools(self):
+        developer_dir = spawn(["/usr/bin/xcode-select", "-print-path"],
+                              check_output=True,
+                              debug=self.debug,
+                              env=self.env)
+
+        return bool(os.path.isdir(developer_dir) and os.path.exists(
+            os.path.join(developer_dir, "usr", "bin", "git")
+        ))
+
     def _assert_requirements(self):
         macos_version = platform.mac_ver()[0]
 
@@ -156,23 +172,33 @@ class Cider(object):
                 "and try again.",
                 macos_version
             )
-        elif not os.path.isdir("/Applications/Xcode.app"):
-            raise XcodeMissingError(
-                "Xcode not installed",
-                "https://itunes.apple.com/us/app/xcode/id497799835?mt=12"
-            )
-        elif spawn(["which", "brew"], check_call=False, debug=self.debug,
-                   stdout=subprocess.PIPE, stderr=subprocess.PIPE):
+
+        if not self._has_xcode_tools():
+            print(tty.progress("Installing the Command Line Tools (expect a "
+                               "GUI popup):"))
+            spawn(["/usr/bin/xcode-select", "--install"],
+                  debug=self.debug, env=self.env)
+            click.pause("Press any key when the installation is complete.")
+            if not self._has_xcode_tools():
+                raise XcodeMissingError(
+                    "Aborted Command Line Tools installation.",
+                )
+
+        if spawn(["which", "brew"], check_call=False, debug=self.debug,
+                 stdout=subprocess.PIPE,
+                 stderr=subprocess.PIPE,
+                 env=self.env):
             raise BrewMissingError(
                 "Homebrew not installed",
                 "http://brew.sh/#install"
             )
 
     @staticmethod
-    def _isstow(symlink, stow):
+    def _islinkkey(symlink, stow):
         return symlink == stow or symlink.startswith(os.path.join(stow, ""))
 
-    def restore(self):
+    def restore(self, ignore_errors=None):
+        ignore_errors = ignore_errors if ignore_errors is not None else False
         self._assert_requirements()
         caskbrew = Brew(True, self.debug, self.verbose)
         homebrew = Brew(False, self.debug, self.verbose)
@@ -202,13 +228,13 @@ class Cider(object):
                         )
                     )
 
-                    caskbrew.safe_install(cask)
+                    caskbrew.safe_install(cask, ignore_errors)
                     del casks[casks.index(cask)]
 
-            homebrew.safe_install(formula)
+            homebrew.safe_install(formula, ignore_errors)
 
         for cask in casks:
-            caskbrew.safe_install(cask)
+            caskbrew.safe_install(cask, ignore_errors)
 
         self.relink()
         self.apply_defaults()
@@ -499,7 +525,8 @@ class Cider(object):
         scripts += bootstrap.get("before-scripts", []) if before else []
         scripts += bootstrap.get("after-scripts", []) if after else []
         for script in scripts:
-            spawn([script], shell=True, debug=self.debug, cwd=self.cider_dir)
+            spawn([script], shell=True, debug=self.debug,
+                  cwd=self.cider_dir, env=self.env)
 
     def set_icon(self, app, icon):
         def transform(icons):
@@ -555,7 +582,7 @@ class Cider(object):
         def transform(symlinks):
             if symlinks:
                 for key in symlinks.keys():
-                    if self._isstow(key, name):
+                    if self._islinkkey(key, name):
                         del symlinks[key]
 
             return symlinks
@@ -597,7 +624,7 @@ class Cider(object):
         removed_targets = set()
         found = False
         for source_glob, target in symlinks.items():
-            if self._isstow(source_glob, name):
+            if self._islinkkey(source_glob, name):
                 found = True
                 for source, target in self.expandtargets(source_glob, target):
                     self._remove_link_target(source, target)
